@@ -1,14 +1,35 @@
 import sys
-import pytz
 import json
 from datetime import datetime
 from typing import Dict, List, Any
 from pathlib import Path
 
 from vnpy.event import EventEngine
-from ..api.hft import TdApi
-from ..api.sip import (
-    MdApi,
+from vnpy.trader.constant import (
+    Direction,
+    Exchange,
+    OrderType,
+    Offset,
+    Product,
+    Status
+)
+from vnpy.trader.gateway import BaseGateway
+from vnpy.trader.utility import round_to, get_folder_path, ZoneInfo
+from vnpy.trader.object import (
+    TickData,
+    OrderData,
+    TradeData,
+    PositionData,
+    AccountData,
+    ContractData,
+    OrderRequest,
+    CancelRequest,
+    SubscribeRequest,
+)
+from vnpy.trader.event import EVENT_TIMER
+
+from ..api.hft import (
+    TdApi,
     AccountType_Stock,
     PositionSide_Long,
     PositionSide_Short,
@@ -29,33 +50,13 @@ from ..api.sip import (
     OrderStatus_Rejected,
     OrderStatus_CancelRejected,
     TradeReportType_Normal,
+)
+from ..api.sip import (
+    MdApi,
     MKtype_SH,
     MKtype_SZ,
 )
-from vnpy.trader.constant import (
-    Direction,
-    Exchange,
-    OrderType,
-    Offset,
-    Product,
-    Status
-)
-from vnpy.trader.gateway import BaseGateway
-from vnpy.trader.utility import round_to, get_folder_path
-from vnpy.trader.object import (
-    TickData,
-    OrderData,
-    TradeData,
-    PositionData,
-    AccountData,
-    ContractData,
-    OrderRequest,
-    CancelRequest,
-    SubscribeRequest,
-)
-from vnpy.trader.event import EVENT_TIMER
-
-from.terminal_info import get_terminal_info
+from .terminal_info import get_terminal_info
 
 
 # 市场映射
@@ -155,7 +156,7 @@ SIDE_VT2HFT: Dict[Any, int] = {
 
 # 其他常量
 MAX_FLOAT = sys.float_info.max                  # 浮点数极限值
-CHINA_TZ = pytz.timezone("Asia/Shanghai")       # 中国时区
+CHINA_TZ = ZoneInfo("Asia/Shanghai")            # 中国时区
 
 # 合约数据全局缓存字典
 symbol_contract_map: Dict[str, ContractData] = {}
@@ -314,9 +315,8 @@ class HftMdApi(MdApi):
 
     def onMarketData(self, mk_type: int, symbol: str, data: dict) -> None:
         """行情数据推送"""
-        timestamp: str = f"{self.date}{str(data['nTime'])}"
-        dt: datetime = datetime.strptime(timestamp, "%Y%m%d%H%M%S%f")
-        dt: datetime = CHINA_TZ.localize(dt)
+        timestamp: str = f"{self.date} {str(data['nTime'])}"
+        dt: datetime = generate_datetime(timestamp)
 
         tick: TickData = TickData(
             symbol=symbol,
@@ -339,7 +339,7 @@ class HftMdApi(MdApi):
         tick.bid_volume_1, tick.bid_volume_2, tick.bid_volume_3, tick.bid_volume_4, tick.bid_volume_5 = data["bid_qty"][0:5]
         tick.ask_volume_1, tick.ask_volume_2, tick.ask_volume_3, tick.ask_volume_4, tick.ask_volume_5 = data["ask_qty"][0:5]
 
-        pricetick = contract.pricetick
+        pricetick: float = contract.pricetick
         if pricetick:
             tick.bid_price_1 = round_to(tick.bid_price_1 / 10000, pricetick)
             tick.bid_price_2 = round_to(tick.bid_price_2 / 10000, pricetick)
@@ -478,13 +478,13 @@ class HftTdApi(TdApi):
     def onDisconnect(self) -> None:
         """服务器连接断开回报"""
         self.login_status = False
-        self.gateway.write_log(f"交易服务器连接断开")
+        self.gateway.write_log("交易服务器连接断开")
 
     def onLogin(self, data: dict, error: dict) -> None:
         """用户登录请求回报"""
         if not error["err_code"]:
             self.login_status = True
-            self.gateway.write_log(f"交易服务器登录成功")
+            self.gateway.write_log("交易服务器登录成功")
 
             self.query_order()
             self.query_trade()
@@ -502,14 +502,13 @@ class HftTdApi(TdApi):
             orderid = sysid
 
         timestamp: str = f"{data['order_date']} {data['order_time']}"
-        dt: datetime = datetime.strptime(timestamp, "%Y%m%d %H%M%S%f")
-        dt: datetime = CHINA_TZ.localize(dt)
+        dt: datetime = generate_datetime(timestamp)
 
         direction, offset = SIDE_HFT2VT[data["side"]]
 
         order: OrderData = self.orders.get(orderid, None)
         if not order:
-            order: OrderData = OrderData(
+            order = OrderData(
                 orderid=orderid,
                 gateway_name=self.gateway_name,
                 symbol=symbol,
@@ -542,8 +541,7 @@ class HftTdApi(TdApi):
             orderid = sysid
 
         timestamp: str = f"{data['trade_date']} {data['trade_time']}"
-        dt: datetime = datetime.strptime(timestamp, "%Y%m%d %H%M%S%f")
-        dt: datetime = CHINA_TZ.localize(dt)
+        dt: datetime = generate_datetime(timestamp)
 
         direction, offset = SIDE_HFT2VT[data["side"]]
 
@@ -578,7 +576,7 @@ class HftTdApi(TdApi):
 
             order.status = Status.REJECTED
             dt: datetime = datetime.now()
-            dt: datetime = CHINA_TZ.localize(dt)
+            dt: datetime = dt.replace(tzinfo=CHINA_TZ)
             order.datetime = dt
             self.gateway.on_order(order)
         else:
@@ -610,7 +608,7 @@ class HftTdApi(TdApi):
 
         pos: PositionData = self.short_positions.get(symbol, None)
         if not pos:
-            pos: PositionData = PositionData(
+            pos = PositionData(
                 gateway_name=self.gateway_name,
                 symbol=symbol,
                 exchange=EXCHANGE_HFT2VT[exchange],
@@ -684,8 +682,7 @@ class HftTdApi(TdApi):
                 self.orderid_sysid_map[orderid] = sysid
 
             timestamp: str = f"{data['order_date']} {data['order_time']}"
-            dt: datetime = datetime.strptime(timestamp, "%Y%m%d %H%M%S%f")
-            dt: datetime = CHINA_TZ.localize(dt)
+            dt: datetime = generate_datetime(timestamp)
 
             direction, offset = SIDE_HFT2VT[data["side"]]
 
@@ -706,10 +703,13 @@ class HftTdApi(TdApi):
             self.orders[orderid] = order
             self.gateway.on_order(order)
 
+            if last:
+                self.query_order(pos)
+
         elif error["err_code"] != 14020:
             self.gateway.write_error(error)
 
-        if last:
+        else:
             self.gateway.write_log("查询委托信息成功")
 
     def onQueryTradeRsp(
@@ -730,8 +730,7 @@ class HftTdApi(TdApi):
                 orderid = sysid
 
             timestamp: str = f"{data['trade_date']} {data['trade_time']}"
-            dt: datetime = datetime.strptime(timestamp, "%Y%m%d %H%M%S%f")
-            dt: datetime = CHINA_TZ.localize(dt)
+            dt: datetime = generate_datetime(timestamp)
 
             direction, offset = SIDE_HFT2VT[data["side"]]
 
@@ -749,10 +748,13 @@ class HftTdApi(TdApi):
             )
             self.gateway.on_trade(trade)
 
+            if last:
+                self.query_trade(pos)
+
         elif error["err_code"] != 14020:
             self.gateway.write_error(error)
 
-        if last:
+        else:
             self.gateway.write_log("查询成交信息成功")
 
     def connect(
@@ -790,6 +792,10 @@ class HftTdApi(TdApi):
 
     def send_order(self, req: OrderRequest) -> str:
         """委托下单"""
+        if req.type not in ORDERTYPE_VT2HFT:
+            self.gateway.write_log(f"当前接口不支持该类型的委托{req.type.value}")
+            return ""
+
         if self.margin_trading and req.offset == Offset.NONE:
             self.gateway.write_log("委托失败，两融交易需要选择开平方向")
             return ""
@@ -808,7 +814,7 @@ class HftTdApi(TdApi):
         order_req: dict = {
             "cl_order_id": orderid,
             "symbol": hft_symbol,
-            "order_type": OrderType_LMT,
+            "order_type": ORDERTYPE_VT2HFT[req.type],
             "volume": int(req.volume),
             "price": int(req.price * 10000),
             "side": SIDE_VT2HFT[(req.direction, req.offset)]
@@ -822,15 +828,25 @@ class HftTdApi(TdApi):
         self.gateway.on_order(order)
         return order.vt_orderid
 
-    def query_order(self) -> None:
+    def query_order(self, pos_str: str = "") -> None:
         """查询未成交委托"""
-        self.reqid += 1
-        self.queryOrders("", 500, self.reqid, 0)
+        hft_req: dict = {
+            "pos_str": pos_str,
+            "query_num": 500
+        }
 
-    def query_trade(self) -> None:
-        """查询成交"""
         self.reqid += 1
-        self.queryTrades("", 500, self.reqid)
+        self.queryOrders(hft_req, self.reqid)
+
+    def query_trade(self, pos_str: str = "") -> None:
+        """查询成交"""
+        hft_req: dict = {
+            "pos_str": pos_str,
+            "query_num": 500
+        }
+
+        self.reqid += 1
+        self.queryTrades(hft_req, self.reqid)
 
     def cancel_order(self, req: CancelRequest) -> None:
         """委托撤单"""
@@ -843,16 +859,21 @@ class HftTdApi(TdApi):
     def query_account(self) -> None:
         """查询资金"""
         self.reqid += 1
-        self.queryCash(self.reqid)
+        self.queryCash({}, self.reqid)
 
     def query_position(self) -> None:
         """查询持仓"""
+        hft_req: dict = {
+            "pos_str": "",
+            "query_num": 500
+        }
+
         self.reqid += 1
-        self.queryPositions("", 500, self.reqid)
+        self.queryPositions(hft_req, self.reqid)
 
         if self.margin_trading:
             self.reqid += 1
-            self.queryCreditShortsell("", 500, self.reqid)
+            self.queryCreditShortsell(hft_req, self.reqid)
 
     def close(self) -> None:
         """关闭连接"""
@@ -860,11 +881,11 @@ class HftTdApi(TdApi):
             self.exit()
 
 
-def adjust_price(price: float) -> float:
-    """将异常的浮点数最大值（MAX_FLOAT）数据调整为0"""
-    if price == MAX_FLOAT:
-        price = 0
-    return price
+def generate_datetime(timestamp: str) -> datetime:
+    """生成时间"""
+    dt: datetime = datetime.strptime(timestamp, "%Y%m%d %H%M%S%f")
+    dt: datetime = dt.replace(tzinfo=CHINA_TZ)
+    return dt
 
 
 def generate_cfg(ip: str, port: int, username: str, password: str) -> str:
